summaryrefslogtreecommitdiffhomepage
path: root/dev/kernel/NewKit
diff options
context:
space:
mode:
Diffstat (limited to 'dev/kernel/NewKit')
-rw-r--r--dev/kernel/NewKit/Array.h4
-rw-r--r--dev/kernel/NewKit/ArrayList.h4
-rw-r--r--dev/kernel/NewKit/Atom.h4
-rw-r--r--dev/kernel/NewKit/Crc32.h4
-rw-r--r--dev/kernel/NewKit/Defines.h6
-rw-r--r--dev/kernel/NewKit/ErrorOr.h4
-rw-r--r--dev/kernel/NewKit/Function.h4
-rw-r--r--dev/kernel/NewKit/Json.h4
-rw-r--r--dev/kernel/NewKit/KString.h4
-rw-r--r--dev/kernel/NewKit/KernelPanic.h12
-rw-r--r--dev/kernel/NewKit/Macros.h30
-rw-r--r--dev/kernel/NewKit/MutableArray.h8
-rw-r--r--dev/kernel/NewKit/OwnPtr.h4
-rw-r--r--dev/kernel/NewKit/PageMgr.h4
-rw-r--r--dev/kernel/NewKit/Pair.h4
-rw-r--r--dev/kernel/NewKit/Pmm.h4
-rw-r--r--dev/kernel/NewKit/Ref.h4
-rw-r--r--dev/kernel/NewKit/Stream.h4
-rw-r--r--dev/kernel/NewKit/Utils.h4
-rw-r--r--dev/kernel/NewKit/Variant.h4
20 files changed, 60 insertions, 60 deletions
diff --git a/dev/kernel/NewKit/Array.h b/dev/kernel/NewKit/Array.h
index 54c09636..43c67586 100644
--- a/dev/kernel/NewKit/Array.h
+++ b/dev/kernel/NewKit/Array.h
@@ -10,7 +10,7 @@
#include <NewKit/ErrorOr.h>
#include <NewKit/Defines.h>
-namespace NeOS
+namespace Kernel
{
template <typename T, SizeT N>
class Array final
@@ -62,4 +62,4 @@ namespace NeOS
{
return Array<ValueType, ARRAY_SIZE(val)>{val};
}
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/ArrayList.h b/dev/kernel/NewKit/ArrayList.h
index 06763b5a..e05480f0 100644
--- a/dev/kernel/NewKit/ArrayList.h
+++ b/dev/kernel/NewKit/ArrayList.h
@@ -8,7 +8,7 @@
#include <NewKit/Defines.h>
-namespace NeOS
+namespace Kernel
{
template <typename T>
class ArrayList final
@@ -60,4 +60,4 @@ namespace NeOS
{
return ArrayList<ValueType>{val};
}
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/Atom.h b/dev/kernel/NewKit/Atom.h
index 3979b0d1..7c908cba 100644
--- a/dev/kernel/NewKit/Atom.h
+++ b/dev/kernel/NewKit/Atom.h
@@ -7,7 +7,7 @@
#include <NewKit/Defines.h>
-namespace NeOS
+namespace Kernel
{
template <typename T>
class Atom final
@@ -44,4 +44,4 @@ namespace NeOS
private:
T fArrayOfAtoms;
};
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/Crc32.h b/dev/kernel/NewKit/Crc32.h
index c3e14413..adc2e7a2 100644
--- a/dev/kernel/NewKit/Crc32.h
+++ b/dev/kernel/NewKit/Crc32.h
@@ -15,9 +15,9 @@
#define kCrcCnt (256)
-namespace NeOS
+namespace Kernel
{
UInt32 ke_calculate_crc32(const Char* crc, Int32 len) noexcept;
-} // namespace NeOS
+} // namespace Kernel
#endif // !CRC32_H
diff --git a/dev/kernel/NewKit/ErrorOr.h b/dev/kernel/NewKit/ErrorOr.h
index 7c879cc8..fb50b21f 100644
--- a/dev/kernel/NewKit/ErrorOr.h
+++ b/dev/kernel/NewKit/ErrorOr.h
@@ -12,7 +12,7 @@
#include <NewKit/Defines.h>
#include <NewKit/Ref.h>
-namespace NeOS
+namespace Kernel
{
using ErrorT = UInt;
@@ -79,4 +79,4 @@ namespace NeOS
using ErrorOrAny = ErrorOr<voidPtr>;
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/Function.h b/dev/kernel/NewKit/Function.h
index d25c06c1..9fa218af 100644
--- a/dev/kernel/NewKit/Function.h
+++ b/dev/kernel/NewKit/Function.h
@@ -3,7 +3,7 @@
#include <NewKit/Defines.h>
-namespace NeOS
+namespace Kernel
{
template <typename T, typename... Args>
class Function final
@@ -48,6 +48,6 @@ namespace NeOS
T(*fFn)
(Args... args);
};
-} // namespace NeOS
+} // namespace Kernel
#endif // !_INC_FUNCTION_H__
diff --git a/dev/kernel/NewKit/Json.h b/dev/kernel/NewKit/Json.h
index 7b53fa4a..a376c15a 100644
--- a/dev/kernel/NewKit/Json.h
+++ b/dev/kernel/NewKit/Json.h
@@ -19,7 +19,7 @@
#define kJSONLen 256
#define kJSONNull "[]"
-namespace NeOS
+namespace Kernel
{
/// @brief JavaScript object class
class Json final
@@ -148,4 +148,4 @@ namespace NeOS
};
using JsonStream = Stream<JsonStreamReader, Json>;
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/KString.h b/dev/kernel/NewKit/KString.h
index e7525a9c..84795c1a 100644
--- a/dev/kernel/NewKit/KString.h
+++ b/dev/kernel/NewKit/KString.h
@@ -14,7 +14,7 @@
#define cMinimumStringSize 8196
-namespace NeOS
+namespace Kernel
{
/// @brief Kernel string class, not dynamic.
class KString final
@@ -91,4 +91,4 @@ namespace NeOS
static bool Equals(const Char* lhs, const Char* rhs);
static bool Equals(const WideChar* lhs, const WideChar* rhs);
};
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/KernelPanic.h b/dev/kernel/NewKit/KernelPanic.h
index 11f9a05d..cd19a1d3 100644
--- a/dev/kernel/NewKit/KernelPanic.h
+++ b/dev/kernel/NewKit/KernelPanic.h
@@ -9,7 +9,7 @@
#include <NewKit/Defines.h>
-namespace NeOS
+namespace Kernel
{
void ke_runtime_check(bool expr, const Char* file, const Char* line);
}
@@ -34,14 +34,14 @@ namespace NeOS
#endif
#define __MUST_PASS(EXPR, FILE, LINE) \
- NeOS::ke_runtime_check(EXPR, FILE, STRINGIFY(LINE))
+ Kernel::ke_runtime_check(EXPR, FILE, STRINGIFY(LINE))
#ifdef __DEBUG__
#define MUST_PASS(EXPR) __MUST_PASS((EXPR), __FILE__, __LINE__)
#define assert(EXPR) MUST_PASS(EXPR)
#else
-#define MUST_PASS(EXPR) (NeOS::Void)(EXPR)
-#define assert(EXPR) (NeOS::Void)(EXPR)
+#define MUST_PASS(EXPR) (Kernel::Void)(EXPR)
+#define assert(EXPR) (Kernel::Void)(EXPR)
#endif
enum RUNTIME_CHECK
@@ -68,7 +68,7 @@ enum RUNTIME_CHECK
typedef enum RUNTIME_CHECK RTL_RUNTIME_CHECK;
-namespace NeOS
+namespace Kernel
{
void ke_panic(const Int32& id, const Char* message = nullptr);
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/Macros.h b/dev/kernel/NewKit/Macros.h
index 1d270929..660877f6 100644
--- a/dev/kernel/NewKit/Macros.h
+++ b/dev/kernel/NewKit/Macros.h
@@ -12,41 +12,41 @@
/***********************************************************************************/
#ifndef KIB
-#define KIB(X) (NeOS::UInt64)((X) / 1024)
+#define KIB(X) (Kernel::UInt64)((X) / 1024)
#endif
#ifndef kib_cast
-#define kib_cast(X) (NeOS::UInt64)((X)*1024)
+#define kib_cast(X) (Kernel::UInt64)((X)*1024)
#endif
#ifndef MIB
-#define MIB(X) (NeOS::UInt64)((NeOS::UInt64)KIB(X) / 1024)
+#define MIB(X) (Kernel::UInt64)((Kernel::UInt64)KIB(X) / 1024)
#endif
#ifndef mib_cast
-#define mib_cast(X) (NeOS::UInt64)((NeOS::UInt64)kib_cast(X) * 1024)
+#define mib_cast(X) (Kernel::UInt64)((Kernel::UInt64)kib_cast(X) * 1024)
#endif
#ifndef GIB
-#define GIB(X) (NeOS::UInt64)((NeOS::UInt64)MIB(X) / 1024)
+#define GIB(X) (Kernel::UInt64)((Kernel::UInt64)MIB(X) / 1024)
#endif
#ifndef gib_cast
-#define gib_cast(X) (NeOS::UInt64)((NeOS::UInt64)mib_cast(X) * 1024)
+#define gib_cast(X) (Kernel::UInt64)((Kernel::UInt64)mib_cast(X) * 1024)
#endif
#ifndef TIB
-#define TIB(X) (NeOS::UInt64)((NeOS::UInt64)GIB(X) / 1024)
+#define TIB(X) (Kernel::UInt64)((Kernel::UInt64)GIB(X) / 1024)
#endif
#ifndef tib_cast
-#define tib_cast(X) ((NeOS::UInt64)gib_cast(X) * 1024)
+#define tib_cast(X) ((Kernel::UInt64)gib_cast(X) * 1024)
#endif
#ifndef ARRAY_SIZE
#define ARRAY_SIZE(a) \
(((sizeof(a) / sizeof(*(a))) / \
- (static_cast<NeOS::Size>(!(sizeof(a) % sizeof(*(a)))))))
+ (static_cast<Kernel::Size>(!(sizeof(a) % sizeof(*(a)))))))
#endif
#define DEPRECATED ATTRIBUTE(deprecated)
@@ -119,10 +119,10 @@
#define CONST const
#define STRINGIFY(X) #X
-#define NE_UNUSED(X) ((NeOS::Void)X)
+#define NE_UNUSED(X) ((Kernel::Void)X)
#ifndef RGB
-#define RGB(R, G, B) (NeOS::UInt32)(R | G << 0x8 | B << 0x10)
+#define RGB(R, G, B) (Kernel::UInt32)(R | G << 0x8 | B << 0x10)
#endif // !RGB
#ifdef __NE_AMD64__
@@ -132,9 +132,9 @@
#endif
#define RTL_ENDIAN(address, value) \
- (((reinterpret_cast<NeOS::Char*>(address)[0]) == (value)) \
- ? (NeOS::Endian::kEndianBig) \
- : (NeOS::Endian::kEndianLittle))
+ (((reinterpret_cast<Kernel::Char*>(address)[0]) == (value)) \
+ ? (Kernel::Endian::kEndianBig) \
+ : (Kernel::Endian::kEndianLittle))
#define Yes true
#define No false
@@ -145,7 +145,7 @@
#define TRUE true
#define FALSE false
-#define BOOL NeOS::Boolean
+#define BOOL Kernel::Boolean
#ifdef RTL_INIT_OBJECT
#undef RTL_INIT_OBJECT
diff --git a/dev/kernel/NewKit/MutableArray.h b/dev/kernel/NewKit/MutableArray.h
index bfb432de..f64c8cad 100644
--- a/dev/kernel/NewKit/MutableArray.h
+++ b/dev/kernel/NewKit/MutableArray.h
@@ -38,7 +38,7 @@
// FIXME: this is a shitty algorithm, which is consumer hungry.
// Remove and occurences of that, and remove that class.
-namespace NeOS
+namespace Kernel
{
template <typename T>
class MutableArray;
@@ -149,7 +149,7 @@ namespace NeOS
MutableLinkedList<T>* fFirstNode{nullptr};
/* Number of nodes inside of this dynamic array. */
- NeOS::SizeT fNodeCount{0};
+ Kernel::SizeT fNodeCount{0};
private:
// don't remove that
@@ -234,6 +234,6 @@ namespace NeOS
MutableLinkedList<T>* fFirstNode{nullptr};
/* Number of nodes inside of this dynamic array. */
- NeOS::SizeT fNodeCount{0};
+ Kernel::SizeT fNodeCount{0};
};
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/OwnPtr.h b/dev/kernel/NewKit/OwnPtr.h
index 169f16d9..5df29d7f 100644
--- a/dev/kernel/NewKit/OwnPtr.h
+++ b/dev/kernel/NewKit/OwnPtr.h
@@ -11,7 +11,7 @@
#include <NewKit/KernelPanic.h>
#include <NewKit/Ref.h>
-namespace NeOS
+namespace Kernel
{
template <typename T>
class OwnPtr;
@@ -91,4 +91,4 @@ namespace NeOS
return ret;
}
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/PageMgr.h b/dev/kernel/NewKit/PageMgr.h
index 00638f8a..e6376233 100644
--- a/dev/kernel/NewKit/PageMgr.h
+++ b/dev/kernel/NewKit/PageMgr.h
@@ -12,7 +12,7 @@
#include <NewKit/Defines.h>
#include <NewKit/Ref.h>
-namespace NeOS
+namespace Kernel
{
class PageMgr;
@@ -78,4 +78,4 @@ namespace NeOS
friend PTEWrapper;
friend class Pmm;
};
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/Pair.h b/dev/kernel/NewKit/Pair.h
index 05a95ff3..74ebf54c 100644
--- a/dev/kernel/NewKit/Pair.h
+++ b/dev/kernel/NewKit/Pair.h
@@ -8,7 +8,7 @@
#include <NewKit/Defines.h>
-namespace NeOS
+namespace Kernel
{
class Pair;
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/Pmm.h b/dev/kernel/NewKit/Pmm.h
index 97bdc0eb..5b90628d 100644
--- a/dev/kernel/NewKit/Pmm.h
+++ b/dev/kernel/NewKit/Pmm.h
@@ -10,7 +10,7 @@
#include <NewKit/PageMgr.h>
#include <NewKit/Ref.h>
-namespace NeOS
+namespace Kernel
{
class Pmm;
class PTEWrapper;
@@ -41,4 +41,4 @@ namespace NeOS
private:
Ref<PageMgr> fPageMgr;
};
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/Ref.h b/dev/kernel/NewKit/Ref.h
index e41bf3bc..45bcf95a 100644
--- a/dev/kernel/NewKit/Ref.h
+++ b/dev/kernel/NewKit/Ref.h
@@ -12,7 +12,7 @@
#include <NewKit/KernelPanic.h>
#include <KernelKit/MemoryMgr.h>
-namespace NeOS
+namespace Kernel
{
template <typename T>
class Ref final
@@ -103,6 +103,6 @@ namespace NeOS
private:
Ref<T> fRef{nullptr};
};
-} // namespace NeOS
+} // namespace Kernel
#endif // ifndef _NEWKIT_REF_H_
diff --git a/dev/kernel/NewKit/Stream.h b/dev/kernel/NewKit/Stream.h
index 541d3389..9a23664d 100644
--- a/dev/kernel/NewKit/Stream.h
+++ b/dev/kernel/NewKit/Stream.h
@@ -10,7 +10,7 @@
#include <NewKit/Defines.h>
#include <NewKit/Ref.h>
-namespace NeOS
+namespace Kernel
{
template <typename StreamTrait, typename Kind>
class Stream final
@@ -55,4 +55,4 @@ namespace NeOS
Ref<StreamTrait> fStream;
Ref<Kind> fKind;
};
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/Utils.h b/dev/kernel/NewKit/Utils.h
index 3df823ef..b455dfce 100644
--- a/dev/kernel/NewKit/Utils.h
+++ b/dev/kernel/NewKit/Utils.h
@@ -9,7 +9,7 @@
#include <NewKit/Defines.h>
-namespace NeOS
+namespace Kernel
{
Int rt_copy_memory(const voidPtr src, voidPtr dst, Size len);
Int rt_move_memory(const voidPtr src, voidPtr dst, Size len);
@@ -27,4 +27,4 @@ namespace NeOS
Int rt_to_lower(Int c);
voidPtr rt_string_in_string(const Char* in, const Char* needle);
char* rt_string_has_char(Char* str, const Char chr);
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/Variant.h b/dev/kernel/NewKit/Variant.h
index 3fa04496..6a0dc1f7 100644
--- a/dev/kernel/NewKit/Variant.h
+++ b/dev/kernel/NewKit/Variant.h
@@ -11,7 +11,7 @@
#include <NewKit/Json.h>
#include <SwapKit/DiskSwap.h>
-namespace NeOS
+namespace Kernel
{
class Variant final
{
@@ -77,4 +77,4 @@ namespace NeOS
voidPtr fPtr{nullptr};
VariantKind fKind{VariantKind::kNull};
};
-} // namespace NeOS
+} // namespace Kernel
diff --git a/dev/kernel/NewKit/Defines.h b/dev/kernel/NewKit/Defines.h
index 7758c053..33759784 100644
--- a/dev/kernel/NewKit/Defines.h
+++ b/dev/kernel/NewKit/Defines.h
@@ -12,7 +12,7 @@
#define NEWKIT_VERSION_BCD 0x01100
#ifndef __cplusplus
#error NeOS compiles with a C++ compiler.
#endif
#if __cplusplus <= 201703L
@@ -28,7 +28,7 @@
#endif
/// @brief The **Kernel** namespace.
-namespace NeOS
+namespace Kernel
{
using voidPtr = void*;
using VoidPtr = void*;
@@ -197,4 +197,4 @@ namespace NeOS
return NO;
}
};
-} // namespace NeOS
+} // namespace Kernel
@@ -12,7 +12,7 @@
#define NEWKIT_VERSION_BCD 0x01100
#ifndef __cplusplus
-#error NeOS compiles with a C++ compiler.
+#error Kernel compiles with a C++ compiler.
#endif
#if __cplusplus <= 201703L